@@ -1,16 +1,27 @@
 package Thread::Tie::Array;
 
+# Make sure we have version info for this module
 # Make sure we do everything by the book from now on
 
-our $VERSION : unique = '0.07';
+$VERSION = '0.08';
 use strict;
 
+# Load only the stuff that we really need
+
+use load;
+
 # Satisfy -require-
 
 1;
 
 #---------------------------------------------------------------------------
 
+# Following subroutines are loaded on demand only
+
+__END__
+
+#---------------------------------------------------------------------------
+
 # standard Perl features
 
 #---------------------------------------------------------------------------
